==> image_preview-1.0.2.tar.gz: lib/image_preview.dart <==
library image_preview;

import 'package:flutter/material.dart';
import 'package:image_preview/src/image_gallery.dart';
import 'package:image_preview/src/image_view.dart';

/// 打开单张图片
void openImagePage(
  NavigatorState navigatorState, {
  required String imgUrl,
  String? imgOriginalUrl,
  String? heroTag,
  String? errorMsg,
  OnLongPressHandler? onLongPressHandler,
  OnPageChanged? onPageChanged,
}) {
  navigatorState.push(MaterialPageRoute<void>(builder: (BuildContext context) {
    return ImageGalleryPage(
      imageUrls: [imgUrl],
      imageOriginalUrls: imgOriginalUrl == null ? null : [imgOriginalUrl],
      heroTags: heroTag == null ? null : [heroTag],
      errorMsg: errorMsg,
      onLongPressHandler: onLongPressHandler,
      onPageChanged: onPageChanged,
    );
  }));
}

/// 打开多张图片
/// [errorMsg] 当图片加载错误时的描述信息
/// [onPageChanged] 切换图片时调用，第一次打开时也会被调用
/// 返回的[Widget]可用于展示图片描述信息，如不需要可返回null
/// [imgOriginalUrls] 原图 会最终加载此图
void openImagesPage(
  NavigatorState navigatorState, {
  required List<String> imgUrls,
  List<String>? imgOriginalUrls,
  List<String>? heroTags,
  int index = 0,
  String? errorMsg,
  OnLongPressHandler? onLongPressHandler,
  OnPageChanged? onPageChanged,
}) {
  navigatorState.push(MaterialPageRoute<void>(builder: (BuildContext context) {
    return ImageGalleryPage(
      imageUrls: imgUrls,
      imageOriginalUrls: imgOriginalUrls,
      heroTags: heroTags,
      errorMsg: errorMsg,
      initialIndex: index,
      onLongPressHandler: onLongPressHandler,
      onPageChanged: onPageChanged,
    );
  }));
}

/// 图片加载变化
/// [infoWidget] 当为null时 此图片对应的没有图片描述信息
typedef Future<Widget?> OnPageChanged(int index, Widget? infoWidget);

==> image_preview-1.0.3.tar.gz: lib/image_preview.dart <==
library image_preview;

import 'package:flutter/material.dart';
import 'package:image_preview/src/image_gallery.dart';
import 'package:image_preview/src/image_view.dart';
import 'package:image_preview/src/page_route.dart';

/// 打开单张图片
void openImagePage(
  NavigatorState navigatorState, {
  required String imgUrl,
  String? imgOriginalUrl,
  String? heroTag,
  String? errorMsg,
  OnLongPressHandler? onLongPressHandler,
  OnPageChanged? onPageChanged,
}) {
  navigatorState.push(NoAnimPageRoute<void>(builder: (BuildContext context) {
    return ImageGalleryPage(
      imageUrls: [imgUrl],
      imageOriginalUrls: imgOriginalUrl == null ? null : [imgOriginalUrl],
      heroTags: heroTag == null ? null : [heroTag],
      errorMsg: errorMsg,
      onLongPressHandler: onLongPressHandler,
      onPageChanged: onPageChanged,
    );
  }));
}

/// 打开多张图片
/// [errorMsg] 当图片加载错误时的描述信息
/// [onPageChanged] 切换图片时调用，第一次打开时也会被调用
/// 返回的[Widget]可用于展示图片描述信息，如不需要可返回null
/// [imgOriginalUrls] 原图 会最终加载此图
void openImagesPage(
  NavigatorState navigatorState, {
  required List<String> imgUrls,
  List<String>? imgOriginalUrls,
  List<String>? heroTags,
  int index = 0,
  String? errorMsg,
  OnLongPressHandler? onLongPressHandler,
  OnPageChanged? onPageChanged,
}) {
  navigatorState.push(NoAnimPageRoute<void>(builder: (BuildContext context) {
    return ImageGalleryPage(
      imageUrls: imgUrls,
      imageOriginalUrls: imgOriginalUrls,
      heroTags: heroTags,
      errorMsg: errorMsg,
      initialIndex: index,
      onLongPressHandler: onLongPressHandler,
      onPageChanged: onPageChanged,
    );
  }));
}

/// 图片加载变化
/// [infoWidget] 当为null时 此图片对应的没有图片描述信息
typedef Future<Widget?> OnPageChanged(int index, Widget? infoWidget);
